// ============================================================
// Project				:	Player_Cinematic
// Author				:	Arekan
// ============================================================
// What? This looks neater! D:
// ============================================================
// Section 1 : Datablocks
// ============================================================
datablock PlayerData(PlayerCinematicArmor : PlayerStandardArmor)
{
	maxForwardSpeed = 6;
	maxBackwardSpeed = 4;
	maxSideSpeed = 6;
	maxForwardCrouchSpeed = 2;
	maxBackwardCrouchSpeed = 2;
	maxSideCrouchSpeed = 2;

	jumpForce = 800;
	airControl = 0.2;

	jumpDelay = 2000;
	runEnergyDrain = 0;
	rechargeRate = 1;
	jumpEnergyDrain = 50;
	canJet = 0;
	canRide = 0;
	uiName = "Cinematic Player";
	showEnergyBar = 1;
	firstPersonOnly = "1";
};

datablock PlayerData(PlayerCinematicSprintingArmor : PlayerCinematicArmor)
{
	runEnergyDrain = 2;
	minJumpEnergy = 75;
	minRunEnergy = 0;
	jumpEnergyDrain = 75;

	jumpDelay = 2000;

	maxForwardSpeed = 10;
	maxBackwardSpeed = 8;
	maxSideSpeed = 8;
	maxForwardCrouchSpeed = 6;
	maxBackwardCrouchSpeed = 4;
	maxSideCrouchSpeed = 4;
	maxUnderwaterForwardSpeed = 16.8;
	maxUnderwaterBackwardSpeed = 15.6;
	maxUnderwaterSideSpeed = 15.6;
	airControl = 0.2;
	uiName = "";
	canRide = 0;
};

function PlayerCinematicArmor::Damage(%data, %player, %sourceObject, %position, %damage, %damageType)
{
	Parent::damage(%data, %player, %sourceObject, %position, %damage, %damageType);

	if(!isObject(%player))
		return;

	if(%player.getDamageLevel() >= 75)
	{
		if(%player.isInDangerState)
		{
			return;
		}
		
		%player.DangerStateSched = schedule(200, 0, "DangerState", %player);
		%player.isInDangerState = true;
	}
}

function PlayerCinematicSprintingArmor::Damage(%data, %player, %sourceObject, %position, %damage, %damageType)
{
	Parent::damage(%data, %player, %sourceObject, %position, %damage, %damageType);

	if(!isObject(%player))
		return;

	if(%player.getDamageLevel() >= 75)
	{
		if(%player.isInDangerState)
		{
			return;
		}
		%player.DangerStateSched = schedule(200, 0, "DangerState", %player);
		%player.changeDatablock(PlayerCinematicArmor);
		%player.isInDangerState = true;
	}
}

// ============================================================
// Section 2 : Functions
// ============================================================
function DangerState(%player)
{
	if(!isObject(%player)) return;

	if(%player.getState() $= "Dead") return;

	%damage = %player.getDamageLevel();

	if(!%player.hasStartedDangerSounds)
	{
		%player.client.play2D("CINEMATIC_DangerStateEnter");
		%player.schedule(1000, mountImage, DangerStateObjectImage, 1);
		%player.hasStartedDangerSounds = true;
	}

	if(%damage >= 75)
	{
		%player.DangerStateSched = schedule(200, 0, "DangerState", %player);
	}
	else
	{
		if(%player.getState() $= "Dead") return;

		%player.isInDangerState = false;
		%player.hasStartedDangerSounds = false;
		%player.client.play2D("CINEMATIC_DangerStateExit");
		%player.schedule(100, unmountImage, 1);
	}
}

function StaminaCheck(%player)
{
	if(!isObject(%player)) return;

	%player.checking = true;
	%stamina = %player.getEnergyLevel();
	if(%stamina <= 0 && %player.getState() !$= "Dead")
	{
		%player.changeDatablock(PlayerCinematicArmor);
		%player.canSprint = false;
		%player.hastoRegen = true;
	}
	if(%stamina == 100 && %player.getState() !$= "Dead" && !%player.canSprint && %player.hastoRegen)
	{
		%player.canSprint = true;
		%player.hastoRegen = false;
	}
	
	%player.staminaSched = schedule(100, 0, "StaminaCheck", %player);
}

// ============================================================
// Section 3 : Packages
// ============================================================
package CinematicSprinting
{
	function servercmdUseTool(%cl,%slot,%data)
	{
		if(!isObject(%cl.player))
			return parent::servercmdUseTool(%cl,%slot,%data);
		if(%cl.player.getDatablock().getName() $= "PlayerCinematicSprintingArmor")
		{
			%cl.stopSprinting();
			%cl.player.canSprint = false;
		}
		if(%cl.player.getDatablock().getName() $= "PlayerCinematicArmor" && %cl.player.getState() !$= "Dead")
		{
			%cl.player.canSprint = false;
		}
		parent::servercmdUseTool(%cl,%slot,%data);
	}
	function servercmdUnUseTool(%cl,%slot,%data)
	{
		if(!isObject(%cl.player))
			return parent::servercmdUseTool(%cl,%slot,%data);
		if(%cl.player.getDatablock().getName() $= "PlayerCinematicArmor" && !%cl.player.hastoRegen && %cl.player.getState() !$= "Dead")
		{
			%cl.player.canSprint = true;
		}
		parent::servercmdUnuseTool(%cl,%slot,%data);
	}
	function Armor::onTrigger(%data,%player,%slot,%io)
	{
		Parent::onTrigger(%data,%player,%slot,%io);
		%client = %player.client;
		if(%io && %data.getName() $= "PlayerCinematicArmor")
		{
			if(%player.checking)
			{
				StaminaCheck(%player);
			}
		}
		if(%player.isEquipping)
		{
			return;
		}
		if(!%player.canSprint)
		{
			return;
		}
		if(%player.isInDangerState)
		{
			return;
		}
		if(%slot == 4)
		{
			if(!%player.checking)
				%player.staminaSched = schedule(100, 0, "StaminaCheck", %player);
			if(%io && %data.getName() $= "PlayerCinematicArmor")
				%player.changeDatablock(PlayerCinematicSprintingArmor);
			else if(!%io && %data.getName() $= "PlayerCinematicSprintingArmor")
				%player.changeDatablock(PlayerCinematicArmor);
		}
	}

  	function GameConnection::SpawnPlayer(%this, %spawn)
  	{
		parent::SpawnPlayer(%this, %spawn);
		%player = %this.player;
		%player.canSprint = true;
		%player.isInDangerState = false;
		%player.hasStartedDangerSounds = false;
		commandToClient( %player.client, 'SetVignette', $EnvGuiServer::VignetteMultiply, $EnvGuiServer::VignetteColor );
	}
	function GameConnection::stopSprinting(%cl)
	{
		if(%cl.player.getDatablock().getName() $= "PlayerCinematicSprintingArmor")
		{
			%cl.player.changeDatablock(PlayerCinematicArmor);
		}
	}
	function gameConnection::onDeath(%cl,%sourceObject,%sourceClient,%damageType,%damageArea)
	{
		parent::onDeath(%cl,%sourceObject,%sourceClient,%damageType,%damageArea);
		if(%sourceObject.isInDangerState)
		{
			%cl.play2d("CINEMATIC_DangerStateExit");
		}
	}
};
activatePackage(CinematicSprinting);